API Reference
=============



:mod:`zgoubi.core`
------------------

.. module:: zgoubi.core

This contains the main PyZgoubi classes: Line and Results

:class:`zgoubi.core.Line`
^^^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: zgoubi.core.Line
	:members:



:class:`zgoubi.core.Results`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: zgoubi.core.Results
	:members:


:mod:`zgoubi.bunch`
-------------------

.. automodule:: zgoubi.bunch
	:members:

:mod:`zgoubi.common`
--------------------

.. automodule:: zgoubi.common
	:members:

:mod:`zgoubi.constants`
-----------------------

.. automodule:: zgoubi.constants
	:members:


:mod:`zgoubi.ellipse`
---------------------

.. automodule:: zgoubi.ellipse
	:members:


:mod:`zgoubi.execptions`
------------------------

.. automodule:: zgoubi.exceptions
	:members:

:mod:`zgoubi.gcp`
-----------------

.. automodule:: zgoubi.gcp
	:members:


:mod:`zgoubi.io`
----------------

.. automodule:: zgoubi.io
	:members:

:mod:`zgoubi.lab_plot`
----------------------

.. automodule:: zgoubi.lab_plot
	:members:

:mod:`zgoubi.rel_conv`
----------------------

.. automodule:: zgoubi.rel_conv
	:members:


:mod:`zgoubi.utils`
-------------------

.. automodule:: zgoubi.utils
	:members:

